@@ -27,7 +27,7 @@ import psutil
 import mimetypes
 from binaryornot.check import is_binary
 
-from settings import (
+from knps.settings import (
     CACHE_FILE_PROCESSING,
     KNPS_SERVER_DEV,
     KNPS_SERVER_PROD
